% Sample initialization for the Saila-Lorda S-R model of the form
% log(R_t) =  log(k)+c_SL*(log(S_t)-log(S_k))+c_SL(1-S_t/S_k)+e, e~N(0,c_t*sigma))
function post_sample = saila_lorda_2_1D_IS_init(T, D, options, cSample)

n_particles = options.solver.n_particles;

hyperparameters = options.model.upm.prior.hyperparameters;

switch lower(options.model.upm.prior.type)
    case 'uniformuniformuniformgamma'
        theta(1,:) = unifrnd(hyperparameters.kLow,hyperparameters.kUp,1,n_particles);
        theta(2,:) = unifrnd(hyperparameters.SkLow,hyperparameters.SkUp,1,n_particles);
        theta(3,:) = unifrnd(hyperparameters.cLow,hyperparameters.cUp,1,n_particles);
        tau = gamrnd(hyperparameters.tauShape,1/hyperparameters.tauScaleInverse,1,n_particles);
        sigma=1./sqrt(tau);
        
        post_sample = [theta ; sigma ; 1/n_particles*ones(1,n_particles)];
    case 'uniformuniformsigmoidalgamma_precision'
        theta(1,:) = unifrnd(hyperparameters.kLow,hyperparameters.kUp,1,n_particles);
        theta(2,:) = unifrnd(hyperparameters.SkLow,hyperparameters.SkUp,1,n_particles);
        theta(3,:) = sigmoidalrnd(n_particles);
        % generate random numbers from the sigmoidal distribution using
        % slice sampler
        if(takeSample==1)
            theta(3,:) = sigmoidalrnd(n_particles);
        else 
            theta(3,:) = cSample;
        end
        tau = gamrnd(hyperparameters.tauShape,1/hyperparameters.tauScaleInverse,1,n_particles);
        sigma=1./sqrt(tau);
        
        post_sample = [theta ; sigma ; 1/n_particles*ones(1,n_particles)];
     case 'uniformuniformsigmoidaluniform' % model with std
        theta(1,:) = unifrnd(hyperparameters.kLow,hyperparameters.kUp,1,n_particles);
        theta(2,:) = unifrnd(hyperparameters.SkLow,hyperparameters.SkUp,1,n_particles);
        if(takeSample==1)
            theta(3,:) = sigmoidalrnd(n_particles);
        else 
            theta(3,:) = cSample;
        end
        % generate random numbers from the sigmoidal distribution using
        % slice sampler
        sigma = unifrnd(hyperparameters.sigmaLow,hyperparameters.sigmaUp,1,n_particles);
        
        post_sample = [theta ; sigma ; 1/n_particles*ones(1,n_particles)];
    case 'uniformuniformsigmoidalgamma' % model with std
        theta(1,:) = unifrnd(hyperparameters.kLow,hyperparameters.kUp,1,n_particles);
        theta(2,:) = unifrnd(hyperparameters.SkLow,hyperparameters.SkUp,1,n_particles);
        if(takeSample==1)
            theta(3,:) = sigmoidalrnd(n_particles);
        else 
            theta(3,:) = cSample;
        end
        % generate random numbers from the sigmoidal distribution using
        % slice sampler
        sigma = gamrnd(hyperparameters.sigmaShape,hyperparameters.sigmaScale,1,n_particles);
        
        post_sample = [theta ; sigma ; 1/n_particles*ones(1,n_particles)];
    case 'uniformuniformsigmoidalisuniform' % model with std
        theta(1,:) = unifrnd(hyperparameters.kLow,hyperparameters.kUp,1,n_particles);
        theta(2,:) = unifrnd(hyperparameters.SkLow,hyperparameters.SkUp,1,n_particles);
        theta(3,:) = unifrnd(hyperparameters.cLow,hyperparameters.cUp,1,n_particles);
        % generate random numbers from the sigmoidal distribution using
        % slice sampler
        sigma = unifrnd(hyperparameters.sigmaLow,hyperparameters.sigmaUp,1,n_particles);
        
        post_sample = [theta ; sigma ; 1/n_particles*ones(1,n_particles)];
     case 'uniformuniformmixuniformuniform' % model with std
        theta(1,:) = unifrnd(hyperparameters.kLow,hyperparameters.kUp,1,n_particles);
        theta(2,:) = unifrnd(hyperparameters.SkLow,hyperparameters.SkUp,1,n_particles);
        theta(3,:) = mixunifrnd(hyperparameters.cLow,hyperparameters.cUp,n_particles);
        sigma = unifrnd(hyperparameters.sigmaLow,hyperparameters.sigmaUp,1,n_particles);
        
        post_sample = [theta ; sigma ; 1/n_particles*ones(1,n_particles)];
     case 'lognormlognormmixuniforminvgamma' % model with std
        theta(1,:) = lognrnd(hyperparameters.kMu,hyperparameters.kSigma,1,n_particles);
        theta(2,:) = lognrnd(hyperparameters.SkMu,hyperparameters.SkSigma,1,n_particles);
        theta(3,:) = mixunifrnd(hyperparameters.cLow,hyperparameters.cUp,n_particles);
        sigma = 1./gamrnd(hyperparameters.sigmaShape,1/hyperparameters.sigmaScale,1,n_particles);
        
        post_sample = [theta ; sigma ; 1/n_particles*ones(1,n_particles)];   
    otherwise
        error('Undefined prior type')
end