% Predictive density evaluation for the Saila-Lorda S-R model of the form
% log(R_t) =  log(k)+c_SL*(log(S_t)-log(S_k))+c_SL(1-S_t/S_k)+e, e~N(0,c_t*sigma)
function pred = saila_lorda_2_1D_IS_predict(post_sample, xnew, options)

% evaluate likelihood
obs = xnew(1); % log(R)
expl = xnew(2); % S
c = xnew(3); % c_t in c_t * sigma, NOT allee parameter c!

pred = zeros(size(post_sample));

switch lower(options.model.upm.likelihood.type)
    case 'normal'
        for i = 1:length(post_sample)
            ks = post_sample{i}(1,:);
            Sks = post_sample{i}(2,:);
            cs = post_sample{i}(3,:);
            sigmas = post_sample{i}(4,:);
            weights = post_sample{i}(5,:);
            
            likelihood = normpdf(obs,...
                                 log(ks)+cs.*(log(expl)-log(Sks))+cs.*(1-expl./Sks)-(sigmas.^2)./2,...
                                 c*sigmas);
            if(i==1 &&...
                   strcmp(options.model.upm.prior.type,'uniformuniformsigmoidalISuniform'))
                    r = 0.6221;
                    scale = 3.1318;
                    sigmoidalf = @(c) sigmoidal(c,r,scale);
                    cweights = (options.model.upm.prior.hyperparameters.cUp-options.model.upm.prior.hyperparameters.cLow).*...
                                feval(sigmoidalf,cs);
                % all weights are 1/N
                pred(i) = sum(cweights.*weights.*likelihood);
            else
                pred(i) = sum(weights.*likelihood);
            end
        end
    case 'student-t'
        error('student-t error not implemented yet')
    case 'uniform'
        error('uniform error not implemented yet')
    otherwise
        error('Undefied error type')                
end