% Predictive density evaluation for the Saila-Lorda S-R model of the form
% log(R_t) =  log(k)+c_SL*(log(S_t)-log(S_k))+c_SL(1-S_t/S_k)+e, e~N(0,c_t*sigma)
function pred = saila_lorda_2_env_factor_1D_IS_predict(post_sample, xnew, options)

% evaluate likelihood
obs = xnew(1); % log(R)
expl = xnew(2); % S
c = xnew(3); % c_t in c_t * sigma, NOT allee parameter c!
env = xnew(4);

pred = zeros(size(post_sample));

switch lower(options.model.upm.likelihood.type)
    case 'normal'
        for i = 1:length(post_sample)
            ks = post_sample{i}(1,:);
            Sks = post_sample{i}(2,:);
            cs = post_sample{i}(3,:);
            ds = post_sample{i}(4,:);
            sigmas = post_sample{i}(5,:);
            weights = post_sample{i}(6,:);
            
            likelihood = normpdf(obs,...
                                 log(ks)+cs.*(log(expl)-log(Sks))+cs.*(1-expl./Sks) +env.*ds -(sigmas.^2)./2,...
                                 c*sigmas);
            pred(i) = sum(weights.*likelihood);
        end
    case 'student-t'
        error('student-t error not implemented yet')
    case 'uniform'
        error('uniform error not implemented yet')
    otherwise
        error('Undefied error type')                
end