% Sample initialization for the Sigmoid Beverton-Holt S-R model of the form
% log(R) =  log(Rmax)-log((1-q)/q*(Sq/S)^c+1)+e, e~N(0,c_t*tau)
function post_sample = sigmoid_beverton_holt_1D_IS_init(T,D,options,cSample)

if (nargin==3 && contains(options.model.upm.prior.type,'sigmoidal'))
    takeSample=1;
else
    takeSample=0;
end

n_particles = options.solver.n_particles;

hyperparameters = options.model.upm.prior.hyperparameters;

switch lower(options.model.upm.prior.type)
    case 'uniformuniformuniformgamma' % model with precision
        theta(1,:) = unifrnd(hyperparameters.RmaxLow,hyperparameters.RmaxUp,1,n_particles);
        theta(2,:) = unifrnd(hyperparameters.SqLow,hyperparameters.SqUp,1,n_particles);
        theta(3,:) = unifrnd(hyperparameters.cLow,hyperparameters.cUp,1,n_particles);
        tau = gamrnd(hyperparameters.tauShape,1/hyperparameters.tauScaleInverse,1,n_particles);
        % generates random numbers from the gamma distribution with 
        %shape parameter hyperparameters.tauShape and scale parameter in
        %1/hyperparameters.tauScaleInverse
        
        post_sample = [theta ; tau ; 1/n_particles*ones(1,n_particles)];
    case 'uniformuniformsigmoidalgamma_precision'
        theta(1,:) = unifrnd(hyperparameters.RmaxLow,hyperparameters.RmaxUp,1,n_particles);
        theta(2,:) = unifrnd(hyperparameters.SqLow,hyperparameters.SqUp,1,n_particles);
        if(takeSample==1)
            theta(3,:) = sigmoidalrnd(n_particles);
        else 
            theta(3,:) = cSample;
        end
        % generate random numbers from the sigmoidal distribution using
        % slice sampler
        tau = gamrnd(hyperparameters.tauShape,1/hyperparameters.tauScaleInverse,1,n_particles);
        % generates random numbers from the gamma distribution with 
        %shape parameter hyperparameters.tauShape and scale parameter in
        %1/hyperparameters.tauScaleInverse
        
        post_sample = [theta ; tau ; 1/n_particles*ones(1,n_particles)];
    case 'uniformuniformsigmoidaluniform' % model with std
        theta(1,:) = unifrnd(hyperparameters.RmaxLow,hyperparameters.RmaxUp,1,n_particles);
        theta(2,:) = unifrnd(hyperparameters.SqLow,hyperparameters.SqUp,1,n_particles);
        if(takeSample==1)
            theta(3,:) = sigmoidalrnd(n_particles);
        else 
            theta(3,:) = cSample;
        end
        % generate random numbers from the sigmoidal distribution using
        % slice sampler
        sigma = unifrnd(hyperparameters.sigmaLow,hyperparameters.sigmaUp,1,n_particles);
        
        post_sample = [theta ; sigma ; 1/n_particles*ones(1,n_particles)];
    case 'uniformuniformsigmoidalgamma' % model with std
        theta(1,:) = unifrnd(hyperparameters.RmaxLow,hyperparameters.RmaxUp,1,n_particles);
        theta(2,:) = unifrnd(hyperparameters.SqLow,hyperparameters.SqUp,1,n_particles);
        if(takeSample==1)
            theta(3,:) = sigmoidalrnd(n_particles);
        else 
            theta(3,:) = cSample;
        end
        % generate random numbers from the sigmoidal distribution using
        % slice sampler
        sigma = gamrnd(hyperparameters.sigmaShape,hyperparameters.sigmaScale,1,n_particles);
        
        post_sample = [theta ; sigma ; 1/n_particles*ones(1,n_particles)];
    case 'uniformuniformsigmoidalisuniform' % model with std
        theta(1,:) = unifrnd(hyperparameters.RmaxLow,hyperparameters.RmaxUp,1,n_particles);
        theta(2,:) = unifrnd(hyperparameters.SqLow,hyperparameters.SqUp,1,n_particles);
        theta(3,:) = unifrnd(hyperparameters.cLow,hyperparameters.cUp,1,n_particles);
        % generate random numbers from the sigmoidal distribution using
        % slice sampler
        sigma = unifrnd(hyperparameters.sigmaLow,hyperparameters.sigmaUp,1,n_particles);
        
        post_sample = [theta ; sigma ; 1/n_particles*ones(1,n_particles)];
    case 'uniformuniformmixuniformuniform' % model with std
        theta(1,:) = unifrnd(hyperparameters.RmaxLow,hyperparameters.RmaxUp,1,n_particles);
        theta(2,:) = unifrnd(hyperparameters.SqLow,hyperparameters.SqUp,1,n_particles);
        theta(3,:) = mixunifrnd(hyperparameters.cLow,hyperparameters.cUp,n_particles);
        % generate random numbers from the sigmoidal distribution using
        % slice sampler
        sigma = unifrnd(hyperparameters.sigmaLow,hyperparameters.sigmaUp,1,n_particles);
        
        post_sample = [theta ; sigma ; 1/n_particles*ones(1,n_particles)];
     case 'lognormlognormmixuniforminvgamma' % model with std
        theta(1,:) = lognrnd(hyperparameters.RmaxMu,hyperparameters.RmaxSigma,1,n_particles);
        theta(2,:) = lognrnd(hyperparameters.SqMu,hyperparameters.SqSigma,1,n_particles);
        theta(3,:) = mixunifrnd(hyperparameters.cLow,hyperparameters.cUp,n_particles);
        % generate random numbers from the sigmoidal distribution using
        % slice sampler
        sigma = 1./gamrnd(hyperparameters.sigmaShape,1/hyperparameters.sigmaScale,1,n_particles);
        
        post_sample = [theta ; sigma ; 1/n_particles*ones(1,n_particles)];
    otherwise
        error('Undefined prior type')
end