% Sample initialization for the Sigmoid Beverton-Holt S-R model with an environmental factor, of the form
% log(R) =  log(Rmax)-log((1-q)/q*(Sq/S)^c+1)+e, e~N(0,c_t*tau)
function post_sample = sigmoid_beverton_holt_env_factor_1D_IS_init(T,D,options)

n_particles = options.solver.n_particles;

hyperparameters = options.model.upm.prior.hyperparameters;

switch lower(options.model.upm.prior.type)
    case 'uniformuniformmixuniformuniformuniform' % model with std
        theta(1,:) = unifrnd(hyperparameters.RmaxLow,hyperparameters.RmaxUp,1,n_particles);
        theta(2,:) = unifrnd(hyperparameters.SqLow,hyperparameters.SqUp,1,n_particles);
        theta(3,:) = mixunifrnd(hyperparameters.cLow,hyperparameters.cUp,n_particles);
        theta(4,:) = unifrnd(hyperparameters.dLow,hyperparameters.dUp,1,n_particles);
        % generate random numbers from the sigmoidal distribution using
        % slice sampler
        sigma = unifrnd(hyperparameters.sigmaLow,hyperparameters.sigmaUp,1,n_particles);
        
        post_sample = [theta ; sigma ; 1/n_particles*ones(1,n_particles)];
    otherwise
        error('Undefined prior type')
end