% Predictive density evaluation for the Sigmoid Beverton-Holt S-R model with an environmental factor, of the form
% log(R) =  log(Rmax)-log((1-q)/q*(Sq/S)^c+1)+d*E+e, e~N(0,c_t*sigma)
function pred = sigmoid_beverton_holt_env_factor_1D_IS_predict(post_sample, xnew, options)

% evaluate likelihood
obs = xnew(1); % check that the data is given correctly in prepareBOCPDDATA.m
expl = xnew(2);
c = xnew(3); % c_t in c_t * tau, not allee parameter c
env = xnew(4);
q = options.model.upm.prior.q;
p = (1-q)/q;

pred = zeros(size(post_sample));

switch lower(options.model.upm.likelihood.type)
    case 'normal'
        for i = 1:length(post_sample)
            Rmaxs = post_sample{i}(1,:);
            Sqs = post_sample{i}(2,:);
            cs = post_sample{i}(3,:);
            ds = post_sample{i}(4,:);
            weights = post_sample{i}(6,:);
            
            sigmas = post_sample{i}(5,:);
            likelihood = normpdf(obs,log(Rmaxs)-log(p*(Sqs/expl).^cs+1) +env.*ds -(sigmas.^2)./2,sigmas);
            pred(i) = sum(weights.*likelihood);
        end
    case 'student-t'
        error('student-t error not implemented yet')
    otherwise
        error('Undefied error type')                
end