function segmentationStartTimes = findRegStartTimesFast(BOCPD_OUTPUT, options)
% 2019/03/27, TP, Developed a more intelligent way to replace the brute force
%                 method that was used earlier

%S = BOCPD_OUTPUT.RSs{end};

% Get rid of zero run lengths
%SS = S(2:end, 2:end)./(1-repmat(S(1, 2:end), size(S, 1)-1, 1));

SS = BOCPD_OUTPUT.RSs{end}; %RSs contains smoothed run 
%length distributions
T = size(SS, 2);

%% find the most likely segmentation

if ~isfield(options.solver, 'minrl')
    minimumSegmentationLength = 3; % minimun length of a regime
else
    minimumSegmentationLength = options.solver.minrl;
end

%%
logSmoothedRunLengthProbabilities = log(SS);
maxCandidates = 10;

%%
segmentations = cell(1,T);
logSegmentationProbabilities = cell(1,T);

%% t = 1
segmentationsTemp = 1;
segmentations{1} = segmentationsTemp;
logSegmentationProbabilitesTemp = logSmoothedRunLengthProbabilities(1, 1);
logSegmentationProbabilities{1} = logSegmentationProbabilitesTemp;

%% t = 2:T
for t = 2:T
    segmentations{t} = [];
    logSegmentationProbabilities{t} = [];
    for i = 1:size(segmentations{t-1}, 1)
        segmentationsTemp = [segmentations{t-1}(i, :) segmentations{t-1}(i, end) + 1];
        if t <= minimumSegmentationLength || segmentations{t-1}(i, end) >= minimumSegmentationLength
            segmentationsTemp = [segmentationsTemp ; segmentations{t-1}(i, :) 1]; %#ok<AGROW>
        end
        segmentations{t} = [segmentations{t} ; segmentationsTemp];
        
        logSegmentationProbabilitesTemp = logSegmentationProbabilities{t-1}(i) + logSmoothedRunLengthProbabilities(segmentationsTemp(:, t), t);
        logSegmentationProbabilities{t} = [logSegmentationProbabilities{t} ; logSegmentationProbabilitesTemp];
    end
    
    if size(segmentations{t}, 1) > maxCandidates
       [~, iSortedByLogProbabilities] = sort(logSegmentationProbabilities{t}, 'descend');
       iSortedByLogProbabilities = iSortedByLogProbabilities(1:maxCandidates);
       iSortedByLogProbabilities = sort(iSortedByLogProbabilities); % if we want them in the original order
       segmentations{t} = segmentations{t}(iSortedByLogProbabilities, :);
       logSegmentationProbabilities{t} = logSegmentationProbabilities{t}(iSortedByLogProbabilities, :);
    end
end

%%
[~, iMaximumSegmentationProbability] = max(logSegmentationProbabilities{T});
isSegmentationStartTime = segmentations{T}(iMaximumSegmentationProbability, :) == 1;
segmentationStartTimes = options.data.time(isSegmentationStartTime)';

