function options = setBOCPDoptions_ICES_raw_plankton(SRmodel,stock_id,variable,sigmaReg,dLow_,dUp_)

% DATA OPTIONS

cd ..
cd('empirical_data');

% stock id
options.data.stocklabel=stock_id;
    
% MODEL OPTIONS
switch SRmodel
    case 'SL'
        options.model.type =  'saila_lorda_2_env_factor'; 
        options.model.upm.type = 'saila_lorda_2_env_factor_1D_IS';
    case 'SBH'
        options.model.type =  'sigmoid_beverton_holt_env_factor'; 
        options.model.upm.type = 'sigmoid_beverton_holt_env_factor_1D_IS';
end

% SET PRIOR TYPES'
options.model.upm.prior.type = 'uniformuniformmixuniformuniformuniform';
options.model.runlength0 = 1;
    
% load data in order to get the maximum of recruits etc.
switch stock_id
    case 'cod7a'
    srData=readtable('cod277a');%use load for .mat
    first_i_ssb=4;
    first_i_recr=4;
    last_i_ssb=0;
    last_i_recr=0;
    first_i_pl=1;
    last_i_pl=-1;
    case 'sol7a'
    srData=readtable('sol277a');%use load for .mat
    first_i_ssb=2;
    first_i_recr=4;
    last_i_ssb=-2;
    last_i_recr=0;
    first_i_pl=1;
    last_i_pl=-3;
    case 'whg7a'
    srData=readtable('whg277a');%use load for .mat
    first_i_ssb=1;
    first_i_recr=1;
    last_i_ssb=0;
    last_i_recr=0;
    first_i_pl=10;
    last_i_pl=-1;
end

ssb = srData.SSB(first_i_ssb:end+last_i_ssb);
Recruits = srData.R(first_i_recr:end+last_i_recr);

recruitsMax=max(Recruits(~isnan(Recruits)));
recruitsMin=min(Recruits(~isnan(Recruits)));
ssbMax=max(ssb(~isnan(ssb)));
ssbMin=min(ssb(~isnan(ssb)));
Year=srData.year(first_i_ssb:end+last_i_ssb);
stockname=stock_id;

options.data.time = Year;
options.data.ssb = ssb; 
options.data.recruits = Recruits;

options.data.stockname=string(stockname(1));

envData=readtable('Raw_and_smoothed_CPR_timeseries_imputed.csv');%use load for .mat

switch variable
    case 'PC1'
        options.data.envfactorname="PC1";
        env_data = envData.PC1(first_i_pl:end+last_i_pl);
    case 'PC2'
        options.data.envfactorname="PC2";
        env_data = envData.PC2(first_i_pl:end+last_i_pl);
end

cd ..

e_mean=mean(env_data);
e_data=env_data-e_mean;
options.data.env_factor=e_data./std(e_data);   

options.data.c=ones(size(Year));

% SET HYPERPARAMETERS ACCORDING TO THE MODEL
switch options.model.upm.prior.type
    case {'uniformuniformmixuniformuniformuniform';}
    switch options.model.type
            case {'saila_lorda_2_env_factor'}
                % HYPERPARAMETERS SPECIFIC TO THE SAILA-LORDA MODEL
                options.model.upm.prior.hyperparameters.kLow = recruitsMin;
                options.model.upm.prior.hyperparameters.kUp = recruitsMax;
                options.model.upm.prior.hyperparameters.SkLow = ssbMin;
                options.model.upm.prior.hyperparameters.SkUp = ssbMax;            
            case {'sigmoid_beverton_holt_env_factor'}
                % HYPERPARAMETERS SPECIFIC TO THE SIGMOIDAL 
                % BEVERTON-HOLT MODEL
                options.model.upm.prior.hyperparameters.RmaxLow = recruitsMin;
                options.model.upm.prior.hyperparameters.RmaxUp = recruitsMax; 
                options.model.upm.prior.hyperparameters.SqLow = ssbMin; 
                options.model.upm.prior.hyperparameters.SqUp = ssbMax; 
        otherwise
            disp('Undefined model in setting hyperparameters.')
    end
    otherwise
        disp('Undefined prior type.')
end

% PRIORS FOR THE DEPENSATION/COMPENSATION PARAMETER AND THE COEFFICIENT OF THE ENVIRONMENTAL
% FACTOR
options.model.upm.prior.hyperparameters.cLow = 0.05;
options.model.upm.prior.hyperparameters.cUp = 5.0;
options.model.upm.prior.hyperparameters.dLow = dLow_;% -2.0;
options.model.upm.prior.hyperparameters.dUp = dUp_; %2.0;
options.model.upm.prior.q=0.5;

% PARAMETERS FOR THE STANDARD DEVIATION OF ERROR (normal distribution)
switch options.model.upm.prior.type
    case {'uniformuniformmixuniformuniformuniform'}
    options.model.upm.prior.hyperparameters.sigmaLow=sigmaReg;
    options.model.upm.prior.hyperparameters.sigmaUp=1.0;
end    
    
options.model.upm.likelihood.type = 'Normal';

% PRIOR FOR THE BEGINNING OF A NEW REGIME
% with the 'constant' option for hazard 
% the expected regime length is 
% 1/options.model.hazard.hyperparameters
options.model.hazard.type = 'constant';
options.model.hazard.hyperparameters=0.1;


% SOLVER OPTIONS
options.solver.type = 'smc';
options.solver.n_particles = 10; % 1e6 for lab computing;
options.solver.h = 0.10;
options.solver.draw_posterior_mixture = false;
end

