function options = setBOCPDoptions_env_combined_ICES_cod(SRmodel,stock_id,sigmaLow_,dLow_,dUp_)

% DATA OPTIONS

cd ..
cd('empirical_data');

% stock id
options.data.stocklabel=stock_id;
    
% MODEL OPTIONS
switch SRmodel
    case 'SL'
        options.model.type =  'saila_lorda_2_env_factor_combined'; 
        options.model.upm.type = 'saila_lorda_2_env_factor_combined_1D_IS';
    case 'SBH'
        options.model.type =  'sigmoid_beverton_holt_env_factor_combined'; 
        options.model.upm.type = 'sigmoid_beverton_holt_env_factor_combined_1D_IS';
end

% SET PRIOR TYPES
options.model.upm.prior.type = 'uniformuniformmixuniformuniformuniformuniform';
options.model.runlength0 = 1;
    
% load data in order to get the maximum of recruits etc.
switch stock_id
    case 'cod7a'
    srData=readtable('cod277a');%use load for .mat
    first_i_ssb=4;
    first_i_recr=4;
    last_i_ssb=0;
    last_i_recr=0;
end

ssb = srData.SSB(first_i_ssb:end+last_i_ssb);
Recruits = srData.R(first_i_recr:end+last_i_recr);

recruitsMax=max(Recruits(~isnan(Recruits)));
recruitsMin=min(Recruits(~isnan(Recruits)));
ssbMax=max(ssb(~isnan(ssb)));
ssbMin=min(ssb(~isnan(ssb)));
Year=srData.year(first_i_ssb:end+last_i_ssb);
stockname=stock_id;

options.data.time = Year;
options.data.ssb = ssb; 
options.data.recruits = Recruits;

options.data.stockname=string(stockname(1));

envData1=readtable('Raw_and_smoothed_CPR_timeseries_imputed.csv');%use load for .mat
envData2=readtable('SST_annual.csv');

options.data.envfactorname="Smoothed PC2 and SST";
env_data1 = envData1.fit_to_PC2(1:end-1);
env_data2 = envData2.sstdegC_cod7a_mean(first_i_ssb:end+last_i_ssb);

% standardize
e1_mean=mean(env_data1);
e1_centralized=env_data1-e1_mean;
e1_std=std(e1_centralized);
e1_data=e1_centralized./e1_std; 
options.data.env_factor1=e1_data;  % plankton 

% standardize
e2_mean=mean(env_data2);
e2_centralized=env_data2-e2_mean;
e2_std=std(e2_centralized);
e2_data=e2_centralized./e2_std; 
options.data.env_factor2=e2_data; % SST

options.data.c=ones(size(Year));

% SET HYPERPARAMETERS ACCORDING TO THE MODEL
switch options.model.upm.prior.type
    case {'uniformuniformmixuniformuniform','uniformuniformmixuniformuniformuniformuniform';}
    switch options.model.type
            case {'saila_lorda_2_env_factor_combined'}
                % HYPERPARAMETERS SPECIFIC TO THE SAILA-LORDA MODEL
                options.model.upm.prior.hyperparameters.kLow = recruitsMin;
                options.model.upm.prior.hyperparameters.kUp = recruitsMax;
                options.model.upm.prior.hyperparameters.SkLow = ssbMin;
                options.model.upm.prior.hyperparameters.SkUp = ssbMax;            
            case {'sigmoid_beverton_holt_env_factor_combined'}
                % HYPERPARAMETERS SPECIFIC TO THE SIGMOIDAL 
                % BEVERTON-HOLT MODEL
                options.model.upm.prior.hyperparameters.RmaxLow = recruitsMin;
                options.model.upm.prior.hyperparameters.RmaxUp = recruitsMax; 
                options.model.upm.prior.hyperparameters.SqLow = ssbMin; 
                options.model.upm.prior.hyperparameters.SqUp = ssbMax; 
        otherwise
            disp('Undefined model in setting hyperparameters.')
    end
    otherwise
        disp('Undefined prior type.')
end

% PRIORS FOR THE DEPENSATION/COMPENSATION PARAMETER AND THE COEFFICIENT OF THE ENVIRONMENTAL
% FACTOR
options.model.upm.prior.hyperparameters.cLow = 0.05;
options.model.upm.prior.hyperparameters.cUp = 5.0;
options.model.upm.prior.hyperparameters.dLow = dLow_; % first env. factor
options.model.upm.prior.hyperparameters.dUp = dUp_;
options.model.upm.prior.hyperparameters.fLow = -2.0; % second env. factor
options.model.upm.prior.hyperparameters.fUp = 2.0;
options.model.upm.prior.q=0.5;

% PARAMETERS FOR THE STANDARD DEVIATION OF ERROR (normal distribution)
switch options.model.upm.prior.type
    case {'uniformuniformsigmoidaluniform','uniformuniformmixuniformuniformuniformuniform'}
    options.model.upm.prior.hyperparameters.sigmaLow=sigmaLow_;
    options.model.upm.prior.hyperparameters.sigmaUp=1.0;
end    
    
options.model.upm.likelihood.type = 'Normal';

% PRIOR FOR THE BEGINNING OF A NEW REGIME
% with the 'constant' option for hazard 
% the expected regime length is 
% 1/options.model.hazard.hyperparameters
options.model.hazard.type = 'constant';
options.model.hazard.hyperparameters=0.1;


% SOLVER OPTIONS
options.solver.type = 'smc';
options.solver.n_particles = 10; % 5*1e6 for lab computing;
options.solver.h = 0.10;
options.solver.draw_posterior_mixture = false;
end

