function options = setBOCPDoptions_env_combined_ICES_sol_and_whg(SRmodel,stock_id,sigmaLow_,dLow_,dUp_,temp,PC_)

% DATA OPTIONS

cd ..
cd('empirical_data');

% stock id
options.data.stocklabel=stock_id;
    
% MODEL OPTIONS
switch SRmodel
    case 'SL'
        options.model.type =  'saila_lorda_2_env_factor_combined'; 
        options.model.upm.type = 'saila_lorda_2_env_factor_combined_1D_IS';
    case 'SBH'
        options.model.type =  'sigmoid_beverton_holt_env_factor_combined'; 
        options.model.upm.type = 'sigmoid_beverton_holt_env_factor_combined_1D_IS';
end

% SET PRIOR TYPES
options.model.upm.prior.type = 'uniformuniformmixuniformuniformuniformuniform';
options.model.runlength0 = 1;
    
% load data in order to get the maximum of recruits etc.
switch stock_id
    case 'sol7a'
    srData=readtable('sol277a');%use load for .mat
    first_i_ssb=2;
    first_i_recr=4;
    last_i_ssb=-2;
    last_i_recr=0;
    first_i_pl=1;
    last_i_pl=-3;
    first_i_sbt=4;
    last_i_sbt=0;
    case 'whg7a'
    srData=readtable('whg277a');%use load for .mat
    first_i_ssb=1;
    first_i_recr=1;
    last_i_ssb=0;
    last_i_recr=0;
    first_i_pl=10;
    last_i_pl=-1;
    first_i_sbt=13;
    last_i_sbt=0;
end

ssb = srData.SSB(first_i_ssb:end+last_i_ssb);
Recruits = srData.R(first_i_recr:end+last_i_recr);

recruitsMax=max(Recruits(~isnan(Recruits)));
recruitsMin=min(Recruits(~isnan(Recruits)));
ssbMax=max(ssb(~isnan(ssb)));
ssbMin=min(ssb(~isnan(ssb)));
Year=srData.year(first_i_ssb:end+last_i_ssb);
stockname=stock_id;

options.data.time = Year;
options.data.ssb = ssb; 
options.data.recruits = Recruits;

options.data.stockname=string(stockname(1));

envData1=readtable('Raw_CPR_timeseries_imputed.csv');%use load for .mat

switch PC_
    case 'PC2'
        options.data.envfactorname="Smoothed PC2 and SBT";
        env_data1 = envData1.fit_to_PC2(first_i_pl:end+last_i_pl);
    case 'PC1'
        options.data.envfactorname="Smoothed PC1 and SBT";
        env_data1 = envData1.fit_to_PC1(first_i_pl:end+last_i_pl);
end


switch temp
    case 6
        options.data.envfactorname="Temperature at depth 6";
        cd('SBT_data')
        envData2=readtable('bottemp_degC_at_depth_6_halfdegree.csv');%use load for .mat
        env_data_raw = envData2.botTemp_degC(first_i_sbt:end+last_i_sbt);
    case 17
        options.data.envfactorname="Temperature at depth 17";
        cd('SBT_data')
        envData2=readtable('bottemp_degC_at_depth_17_halfdegree.csv');%use load for .mat
        env_data_raw = envData2.botTemp_degC(first_i_sbt:end+last_i_sbt);
    case 27
        options.data.envfactorname="Temperature at depth 27";
        cd('SBT_data')
        envData2=readtable('bottemp_degC_at_depth_27_halfdegree.csv');%use load for .mat
        env_data_raw = envData2.botTemp_degC(first_i_sbt:end+last_i_sbt);
    case 37
        options.data.envfactorname="Temperature at depth 37";
        cd('SBT_data')
        envData2=readtable('bottemp_degC_at_depth_37_halfdegree.csv');%use load for .mat
        env_data_raw = envData2.botTemp_degC(first_i_sbt:end+last_i_sbt);
    case 47
        options.data.envfactorname="Temperature at depth 47";
        cd('SBT_data')
        envData2=readtable('bottemp_degC_at_depth_47_halfdegree.csv');%use load for .mat
        env_data_raw = envData2.botTemp_degC(first_i_sbt:end+last_i_sbt);
end


% take a weighted average
switch stock_id
    case 'sol7a'
        env_data2 = 0.5*env_data_raw(1:end-2) + env_data_raw(2:end-1) + env_data_raw(3:end);  
    otherwise
        env_data2=env_data_raw;
end


% standardize
e1_mean=mean(env_data1);
e1_centralized=env_data1-e1_mean;
e1_std=std(e1_centralized);
e1_data=e1_centralized./e1_std; 
options.data.env_factor1=e1_data;  % plankton 

% standardize
e2_mean=mean(env_data2);
e2_centralized=env_data2-e2_mean;
e2_std=std(e2_centralized);
e2_data=e2_centralized./e2_std; 
options.data.env_factor2=e2_data; % SBT

options.data.c=ones(size(Year));

% SET HYPERPARAMETERS ACCORDING TO THE MODEL
switch options.model.upm.prior.type
    case {'uniformuniformmixuniformuniform','uniformuniformmixuniformuniformuniformuniform';}
    switch options.model.type
            case {'saila_lorda_2_env_factor_combined'}
                % HYPERPARAMETERS SPECIFIC TO THE SAILA-LORDA MODEL
                options.model.upm.prior.hyperparameters.kLow = recruitsMin;
                options.model.upm.prior.hyperparameters.kUp = recruitsMax;
                options.model.upm.prior.hyperparameters.SkLow = ssbMin;
                options.model.upm.prior.hyperparameters.SkUp = ssbMax;            
            case {'sigmoid_beverton_holt_env_factor_combined'}
                % HYPERPARAMETERS SPECIFIC TO THE SIGMOIDAL 
                % BEVERTON-HOLT MODEL
                options.model.upm.prior.hyperparameters.RmaxLow = recruitsMin;
                options.model.upm.prior.hyperparameters.RmaxUp = recruitsMax; 
                options.model.upm.prior.hyperparameters.SqLow = ssbMin; 
                options.model.upm.prior.hyperparameters.SqUp = ssbMax; 
        otherwise
            disp('Undefined model in setting hyperparameters.')
    end
    otherwise
        disp('Undefined prior type.')
end

% PRIORS FOR THE DEPENSATION/COMPENSATION PARAMETER AND THE COEFFICIENT OF THE ENVIRONMENTAL
% FACTOR
options.model.upm.prior.hyperparameters.cLow = 0.05;
options.model.upm.prior.hyperparameters.cUp = 5.0;
options.model.upm.prior.hyperparameters.dLow = dLow_; % first env. factor (PC)
options.model.upm.prior.hyperparameters.dUp = dUp_;
options.model.upm.prior.hyperparameters.fLow = -2.0; % second env. factor (SBT)
options.model.upm.prior.hyperparameters.fUp = 2.0;
options.model.upm.prior.q=0.5;

% PARAMETERS FOR THE STANDARD DEVIATION OF ERROR (normal distribution)
switch options.model.upm.prior.type
    case {'uniformuniformsigmoidaluniform','uniformuniformmixuniformuniformuniformuniform'}
    options.model.upm.prior.hyperparameters.sigmaLow=sigmaLow_;
    options.model.upm.prior.hyperparameters.sigmaUp=1.0;
end    
    
options.model.upm.likelihood.type = 'Normal';

% PRIOR FOR THE BEGINNING OF A NEW REGIME
% with the 'constant' option for hazard 
% the expected regime length is 
% 1/options.model.hazard.hyperparameters
options.model.hazard.type = 'constant';
options.model.hazard.hyperparameters=0.1;


% SOLVER OPTIONS
options.solver.type = 'smc';
options.solver.n_particles = 10; % 5*1e6 for lab computing;
options.solver.h = 0.10;
options.solver.draw_posterior_mixture = false;
end

