function [Data, options] = prepareBOCPDDATA_env(options)

iNaNs = isnan(options.data.recruits) | isnan(options.data.ssb);
options.data.recruits = options.data.recruits(~iNaNs);
options.data.ssb = options.data.ssb(~iNaNs);
options.data.c = options.data.c(~iNaNs);
options.data.time = options.data.time(~iNaNs);
options.data.env_factor = options.data.env_factor(~iNaNs);

R = options.data.recruits;
S = options.data.ssb;
c = options.data.c; 
e = options.data.env_factor;

switch lower(options.model.type)
    case 'ricker_lin_reg'
        Data(:,1) = log(R(:)./S(:));
        Data(:,2) = ones(length(S),1);
        Data(:,3) = -S(:);
        Data(:,4) = c;
    case 'ricker'
        Data(:,1) = log(R(:)./S(:));
        Data(:,2) = S(:);
        Data(:,3) = c;
    case 'ricker_2'
        Data(:,1) = log(R(:)./S(:));
        Data(:,2) = S(:);
        Data(:,3) = c;
    case 'ricker_3'
        Data(:,1) = log(R(:)./S(:));
        Data(:,2) = S(:);
        Data(:,3) = c;
    case 'ricker_4'
        Data(:,1) = log(R(:)./S(:));
        Data(:,2) = S(:);
        Data(:,3) = c;
    case 'ricker_logn'
        Data(:,1) = R(:);
        Data(:,2) = S(:);
        Data(:,3) = c;
    case 'beverton_holt'
        Data(:,1) = log(R(:));
        Data(:,2) = S(:);
        Data(:,3) = c;
    case 'beverton_holt_2'
        Data(:,1) = log(R(:)./S(:));
        Data(:,2) = S(:);
        Data(:,3) = c;
    case 'beverton_holt_3'
        Data(:,1) = log(R(:)./S(:));
        Data(:,2) = S(:);
        Data(:,3) = c;
    case 'beverton_holt_4'
        Data(:,1) = log(R(:)./S(:));
        Data(:,2) = S(:);
        Data(:,3) = c;
    case 'beverton_holt_5'
        Data(:,1) = log(R(:)./S(:));
        Data(:,2) = S(:);
        Data(:,3) = c;
    case 'beverton_holt_6'
        Data(:,1) = log(R(:)./S(:));
        Data(:,2) = S(:);
        Data(:,3) = c;        
    %Should these be given in the same form for all models?
    case {'saila_lorda', 'saila_lorda_2','saila_lorda_2_constant_error',...
            'saila_lorda_reduced'}
        Data(:,1) = log(R(:));
        Data(:,2) = S(:);
        Data(:,3) = c; %this is related to scaling the variance 
        %when sampling intensity changes
    case {'saila_lorda_2_env_factor'}
        Data(:,1) = log(R(:));
        Data(:,2) = S(:);
        Data(:,3) = c; %this is related to scaling the variance 
        %when sampling intensity changes
        Data(:,4) = e;
    case {'sigmoid_beverton_holt','sigmoid_beverton_holt_constant_error',...
            'sigmoid_beverton_holt_reduced'} % check that this corresponds to _predict.main
        Data(:,1) = log(R(:));
        Data(:,2) = S(:);
        Data(:,3) = c; 
    case {'sigmoid_beverton_holt_env_factor'} % check that this corresponds to _predict.main
        Data(:,1) = log(R(:));
        Data(:,2) = S(:);
        Data(:,3) = c; 
        Data(:,4) = e;
    otherwise
        error('Undefined model type')
end
